import { ResourceProps } from 'aws-cdk-lib';
import { DefaultInstanceTenancy, GatewayVpcEndpointOptions, SubnetSelection, VpnConnectionOptions } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { FlowLogOptions, FourTierNetwork } from '.';
import { FourTierNetworkSpoke } from './four-tier-network-spoke';
import { TransitGatewayProps } from '../ec2';
import { ITransitGateway } from '../ec2/transit-gateway';
import { ISharedPrincipal } from '../ram';
export interface FourTierNetworkShareProperties {
    readonly autoAddAccounts?: boolean;
    readonly allowExternalPrincipals?: boolean;
    readonly pricipals?: ISharedPrincipal[];
}
export interface AddSpokeNetworkProps {
    readonly availabilityZones?: string[];
    readonly cidr?: string;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly flowLogs?: {
        [id: string]: FlowLogOptions;
    };
    readonly gatewayEndpoints?: {
        [id: string]: GatewayVpcEndpointOptions;
    };
    readonly maxAzs?: number;
    readonly vpcName?: string;
    readonly vpnConnections?: {
        [id: string]: VpnConnectionOptions;
    };
    readonly vpnGateway?: boolean;
    readonly vpnGatewayAsn?: number;
    readonly vpnRoutePropagation?: SubnetSelection[];
}
export interface FourTierNetworkHubProps extends ResourceProps {
    readonly availabilityZones?: string[];
    readonly cidr?: string;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly flowLogs?: {
        [id: string]: FlowLogOptions;
    };
    readonly gatewayEndpoints?: {
        [id: string]: GatewayVpcEndpointOptions;
    };
    readonly maxAzs?: number;
    readonly sharing?: FourTierNetworkShareProperties;
    readonly vpcName?: string;
    readonly vpnConnections?: {
        [id: string]: VpnConnectionOptions;
    };
    readonly vpnGateway?: boolean;
    readonly vpnGatewayAsn?: number;
    readonly vpnRoutePropagation?: SubnetSelection[];
}
export declare class FourTierNetworkHub extends FourTierNetwork {
    private readonly _flowLogConfiguration?;
    private readonly _sharedAccounts;
    private _resourceShare?;
    private _transitGateway?;
    readonly sharing: FourTierNetworkShareProperties;
    get transitGateway(): ITransitGateway | undefined;
    constructor(scope: IConstruct, id: string, props?: FourTierNetworkHubProps);
    private _addSharedAccount;
    private _enableResourceShare;
    addSpoke(scope: IConstruct, id: string, props?: AddSpokeNetworkProps): FourTierNetworkSpoke;
    enableTransitGateway(props?: TransitGatewayProps): ITransitGateway;
}
